--[[
-- Generic Keybindings for all files
--]]

local keymap = vim.api.nvim_set_keymap
local default_ops = { noremap = true, silent = true }

-- Quick escape insert mode
keymap('i', 'jk', '<Esc>', default_ops)

-- Delete single character without copying into register
keymap("n", "x", '"_x', default_ops)

-- Window management
keymap("n", "<leader>sv", "<C-w>v", default_ops)
keymap("n", "<leader>sh", "<C-w>s", default_ops)
keymap("n", "<leader>se", "<C-w>=", default_ops)
keymap("n", "<leader>sx", ":close<CR>", default_ops)

-- Save, Save/Quit
keymap('n', '<F1>', ':w<CR>', default_ops)
keymap('n', '<F2>', ':wq<CR>', default_ops)

-- Tab through open buffers
keymap('n', '[b', ':bp<CR>', default_ops)
keymap('n', ']b', ':bn<CR>', default_ops)

-- Enter lines
keymap('n', '<Enter>', 'o<Esc>', default_ops)
keymap('n', '<s-Enter>', 'O<Esc>', default_ops)

-- Folding
keymap('n', '<space>', 'za', default_ops)

-- Telescope stuff
keymap('n', '<Leader>ff', ':Telescope find_files hidden=true<CR>', default_ops)
keymap('n', '<Leader>fs', ':Telescope live_grep<CR>', default_ops)
keymap('n', '<Leader>fr', ':Telescope oldfiles<CR>', default_ops)
keymap('n', '<Leader>d', ':Telescope diagnostics<CR>', default_ops)
keymap('n', '<Leader>h', ':Telescope neoclip<CR>', default_ops)
keymap('n', '<Leader>b', ':Telescope buffers<CR>', default_ops)
keymap('n', '<Leader>c', ':Telescope colorscheme<CR>', default_ops)
keymap('n', '<Leader>?', ':Telescope help_tags<CR>', default_ops)
keymap('n', '<Leader>fb', ':Telescope file_browser hidden=true grouped=true sorting_strategy=ascending<CR>', default_ops)

-- Shift up and down
keymap("v", "J", ":m '>+1<CR>gv=gv", default_ops)
keymap("v", "K", ":m '<-2<CR>gv=gv", default_ops)

-- Keep centered
keymap("n", "<C-d>", "<C-d>zz", default_ops)
keymap("n", "<C-u>", "<C-u>zz", default_ops)
keymap("n", "n", "nzzzv", default_ops)
keymap("n", "N", "Nzzzv", default_ops)
keymap("n", "G", "Gzz", default_ops)
keymap("n", "{", "{zz", default_ops)
keymap("n", "}", "}zz", default_ops)

-- Yank to system clipboard
keymap("n", "<leader>y", [["+y]], default_ops)
keymap("v", "<leader>y", [["+y]], default_ops)
keymap("n", "<leader>Y", [["+Y]], default_ops)

-- Replace the word the cursor is currently on
keymap("n", "<leader>s", [[:%s/\<<C-r><C-w>\>/<C-r><C-w>/gI<Left><Left><Left>]], default_ops)

-- Git
keymap('n', '<Leader>gg', ':LazyGit<CR>', default_ops)
keymap('n', '<Leader>gf', ':Telescope git_files<CR>', default_ops)
keymap('n', '<Leader>gb', ':Gitsigns toggle_deleted<CR>', default_ops)
keymap('n', ']h', ':Gitsigns next_hunk<CR>', default_ops)
keymap('n', '[h', ':Gitsigns prev_hunk<CR>', default_ops)
keymap('n', '<Leader>gr', ':Gitsigns reset_hunk<CR>', default_ops)
keymap('n', '<Leader>gp', ':Gitsigns preview_hunk<CR>', default_ops)
keymap('n', '<Leader>gs', ':Gitsigns stage_hunk<CR>', default_ops)
keymap('n', '<Leader>gu', ':Gitsigns undo_stage_hunk<CR>', default_ops)

-- File Explorer
keymap('n', '<Leader>e', ':NeoTreeFocusToggle<CR>', default_ops)

-- Object Explorer
keymap('n', '<Leader>o', ':SymbolsOutline<CR>', default_ops)

-- Debugging
keymap('n', '<Leader>B', ":lua require'dap'.toggle_breakpoint()<CR>", default_ops)
keymap('n', '<F5>', ":lua require'dap'.continue()<CR>", default_ops)
keymap('n', '<F6>', ":lua require'dap'.step_into()<CR>", default_ops)
keymap('n', '<F7>', ":lua require'dap'.step_over()<CR>", default_ops)
keymap('n', '<Leader>D', ":lua require'dapui'.toggle()<CR>", default_ops)

-- REPL
keymap('v', '<Leader>x', ':ToggleTermSendVisualLines 100<CR><CR><CR>', default_ops)
keymap('n', '<Leader>x', ':ToggleTermSendCurrentLine 100<CR><CR>', default_ops)


-- Helpful stuff for ToggleTerm, taken from their docs
function _G.set_terminal_keymaps()
  local opts = {buffer = 0}
  vim.keymap.set('t', '<esc>', [[<C-\><C-n>]], opts)
  vim.keymap.set('t', 'jk', [[<C-\><C-n>]], opts)
  vim.keymap.set('t', '<C-h>', [[<Cmd>wincmd h<CR>]], opts)
  vim.keymap.set('t', '<C-j>', [[<Cmd>wincmd j<CR>]], opts)
  vim.keymap.set('t', '<C-k>', [[<Cmd>wincmd k<CR>]], opts)
  vim.keymap.set('t', '<C-l>', [[<Cmd>wincmd l<CR>]], opts)
  vim.keymap.set('t', '<C-w>', [[<C-\><C-n><C-w>]], opts)
end
-- if you only want these mappings for toggle term use term://*toggleterm#* instead
vim.cmd('autocmd! TermOpen term://* lua set_terminal_keymaps()')

-- Toggle a custom Terminal with ipython
local Terminal = require('toggleterm.terminal').Terminal
local ipython = Terminal:new({ cmd="ipython", direction="horizontal", count=100})
function _ipython_toggle()
	ipython:toggle()
end
keymap('n', '<F1>', ":lua _ipython_toggle()<CR><Cmd>wincmd k<CR>", default_ops)
keymap('i', '<F1>', "<Esc>:lua _ipython_toggle()<CR><Cmd>wincmd k<CR>", default_ops)
keymap('t', '<F1>', "<Esc><Cmd>wincmd k<CR>:lua _ipython_toggle()<CR>", default_ops)
